@@ -121,6 +121,10 @@ class SwitchGuideStepDefinitionUiAssets(BaseModel):
     In the future it could also be warnings and errors.
     """
     stepBannerType: Optional[str] = None
+    """Treat step as a promotional step with limited function.
+    Purely for cosmetic purposes. Specific limitations should be handled by other means.
+    """
+    isPromotional: Optional[bool] = False
 
 
 class SwitchGuideStepDefinition(BaseModel):
